@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2020 openpyxl
+# Copyright (c) 2010-2021 openpyxl
 
 """Manage individual cells in a spreadsheet.
 
@@ -37,12 +37,6 @@ TIME_FORMATS = {
     datetime.time:numbers.FORMAT_DATE_TIME6,
     datetime.timedelta:numbers.FORMAT_DATE_TIMEDELTA,
                 }
-try:
-    from pandas import Timestamp
-    TIME_TYPES = TIME_TYPES + (Timestamp,)
-    TIME_FORMATS[Timestamp] = numbers.FORMAT_DATE_DATETIME
-except ImportError:
-    pass
 
 STRING_TYPES = (str, bytes)
 KNOWN_TYPES = NUMERIC_TYPES + TIME_TYPES + STRING_TYPES + (bool, type(None))
@@ -83,6 +77,18 @@ def get_type(t, value):
     return dt
 
 
+def get_time_format(t):
+    value = TIME_FORMATS.get(t)
+    if value:
+        return value
+    for base in t.mro()[1:]:
+        value = TIME_FORMATS.get(base)
+        if value:
+            TIME_FORMATS[t] = value
+            return value
+    raise ValueError("Could not get time format for {0!r}".format(value))
+
+
 class Cell(StyleableObject):
     """Describes cell associated properties.
 
@@ -177,16 +183,15 @@ class Cell(StyleableObject):
         except KeyError:
             dt = get_type(t, value)
 
-        if dt is not None:
+        if dt is None and value is not None:
+            raise ValueError("Cannot convert {0!r} to Excel".format(value))
+
+        if dt:
             self.data_type = dt
 
-        if dt == 'n' or dt == 'b':
-            pass
-
-        elif dt == 'd':
+        if dt == 'd':
             if not is_date_format(self.number_format):
-                self.number_format = TIME_FORMATS[t]
-            self.data_type = "d"
+                self.number_format = get_time_format(t)
 
         elif dt == "s":
             value = self.check_string(value)
@@ -195,9 +200,6 @@ class Cell(StyleableObject):
             elif value in ERROR_CODES:
                 self.data_type = 'e'
 
-        elif value is not None:
-            raise ValueError("Cannot convert {0!r} to Excel".format(value))
-
         self._value = value
 
 
