@@ -1,9 +1,10 @@
-# Copyright (c) 2010-2020 openpyxl
+# Copyright (c) 2010-2021 openpyxl
 
 """
 Collection of utilities used within the package and also available for client code
 """
 import re
+from string import digits
 
 from .exceptions import CellCoordinatesException
 
@@ -56,13 +57,12 @@ def absolute_coordinate(coord_string):
     """Convert a coordinate to an absolute coordinate string (B12 -> $B$12)"""
     m = ABSOLUTE_RE.match(coord_string)
     if not m:
-        raise ValueError("{0} is not a valid coordinate range".format(
-            coord_string))
+        raise ValueError(f"{coord_string} is not a valid coordinate range")
 
     d = m.groupdict('')
     for k, v in d.items():
         if v:
-            d[k] = "${0}".format(v)
+            d[k] = f"${v}"
 
     if d['max_col'] or d['max_row']:
         fmt = "{min_col}{min_row}:{max_col}{max_row}"
@@ -194,8 +194,11 @@ def coordinate_to_tuple(coordinate):
     """
     Convert an Excel style coordinate to (row, colum) tuple
     """
-    match = COORD_RE.split(coordinate)
-    col, row = match[1:3]
+    for idx, c in enumerate(coordinate):
+        if c in digits:
+            break
+    col = coordinate[:idx].upper()
+    row = coordinate[idx:]
     return int(row), _COL_STRING_CACHE[col]
 
 
